#[macro_export]
macro_rules! assert_vec_tol {
    ($a:expr, $b:expr, $tolerance:expr) => {{
        let a = $a;
        let b = $b;
        let tolerance = $tolerance;

        if a.len() != b.len() {
            panic!("Vectors have different lengths: {} != {}", a.len(), b.len());
        }

        for (i, (&val_a, &val_b)) in a.iter().zip(b.iter()).enumerate() {
            if (val_a - val_b).abs() >= tolerance {
                panic!(
                    "Values at index {} differ by more than the tolerance: {} != {} (tolerance = {})",
                    i, val_a, val_b, tolerance
                );
            }
        }
    }};
}
